@@ -789,12 +789,12 @@ function reports_item_edit() {
 
 	form_save_button(get_reports_page() . '?action=edit&tab=items&id=' . get_request_var('id'), 'return');
 
-	if (isset($item['item_type']) && $item['item_type'] == REPORTS_ITEM_GRAPH) {
+	if (isset($reports_item['item_type']) && $reports_item['item_type'] == REPORTS_ITEM_GRAPH) {
 		$timespan = array();
 		# get config option for first-day-of-the-week
 		$first_weekdayid = read_user_setting('first_weekdayid');
 		# get start/end time-since-epoch for actual time (now()) and given current-session-timespan
-		get_timespan($timespan, time(), $item['timespan'], $first_weekdayid);
+		get_timespan($timespan, time(), $reports_item['timespan'], $first_weekdayid);
 	}
 
 	/* don't cache previews */
@@ -806,7 +806,6 @@ function reports_item_edit() {
 	useCss=<?php print ($report['cformat'] == 'on' ? 'true':'false');?>;
 
 	function toggle_item_type() {
-		//console.log($('#item_type').val());
 		// right bracket ')' does not come with a field
 		if ($('#item_type').val() == '<?php print REPORTS_ITEM_GRAPH;?>') {
 			$('#row_align').show();
